# -*- coding: utf-8 -*-

################################################################
# imports
#
from distutils.core import setup
from distutils.extension import Extension
import os.path
import platform
import sys

################################################################
# OS dependent settings
#
osname = platform.system()

if osname == "Windows":
    libraries = ['ziPython.pyd']
    requires = ['numpy']
    library_dirs = ['../']
elif osname == "Linux":
    requires = ['numpy']
    libraries = ['ziPython.so']
    library_dirs = ['../']
else:
    print "The OS '" + osname + "' is not supported. Exit."
    sys.exit(1)

################################################################
# version checks
#
if sys.maxunicode == 1114111:
    ucs = 'ucs4'
else:
    ucs = 'ucs2'

pyver = sys.version[0:3]
arch  = platform.architecture()[0]

if pyver != '2.6' or ucs != 'ucs4'  or arch != '32bit':
    print "You are using Python " + arch + " " + pyver + " with Unicode " + ucs + "."
    print "But this ziPython requires Python 32bit 2.6 with Unicode ucs4."
    print "Installation exits."
    print ""
    print "Please download another version that corresponds to your Python system."
    print ""
    sys.exit(1)

################################################################
# pypi classifiers
#
classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Natural Language :: English',
    'Operating System :: Microsoft :: Windows',
    'Operating System :: POSIX :: Linux',
    'Programming Language :: C++',
    'Programming Language :: Python :: 2.6',
    'Topic :: Software Development :: Libraries :: Python Modules',
    ]


################################################################
# main section
#
setup(name='ziPython',
      version='15.11.34635',
      description='Python Driver for Zurich Instrument Devices',
      author='Zurich Instruments AG',
      author_email='info@zhinst.com',
      url='http://www.zhinst.com',
      platforms=["windows", "Linux"],
      requires=requires,
      classifiers=classifiers,
      include_dirs=library_dirs,
      packages=['zhinst',
                'zhinst.examples',
                'zhinst.examples.common',
                'zhinst.examples.hf2',
                'zhinst.examples.uhf'],
      package_dir={'zhinst': 'zhinst'},
      package_data={'zhinst': libraries},
      )



